<?php

namespace ltcms\console\input;

class Argument
{
    // 必传参数
    const REQUIRED = 1;

    // 可选参数
    const OPTIONAL = 2;

    // 数组参数
    const IS_ARRAY = 4;

    /**
     * 参数名
     * @var string
     */
    private $name;

    /**
     * 参数类型
     * @var int
     */
    private $mode;

    /**
     * 参数默认值
     * @var mixed
     */
    private $default;

    /**
     * 参数描述
     * @var string
     */
    private $description;

    /**
     * 构造方法
     */
    public function __construct($name, $mode = null, $description = '', $default = null)
    {
        if (null === $mode) {
            $mode = self::OPTIONAL;
        }

        $this->name        = $name;
        $this->mode        = $mode;
        $this->description = $description;

        $this->setDefault($default);
    }

    /**
     * 设置默认值
     * @param mixed $default 默认值
     */
    public function setDefault($default = null)
    {
        $this->default = $default;
    }

    /**
     * 该参数是否接受数组
     */
    public function isArray()
    {
        return self::IS_ARRAY === (self::IS_ARRAY & $this->mode);
    }

    /**
     * 获取默认值
     * @return mixed
     */
    public function getDefault()
    {
        return $this->default;
    }

    /**
     * 获取参数名
     * @return string
     */
    public function getName()
    {
        return $this->name;
    }

    /**
     * 是否必须
     * @return bool
     */
    public function isRequired()
    {
        return self::REQUIRED === (self::REQUIRED & $this->mode);
    }

    /**
     * 获取描述
     * @return string
     */
    public function getDescription()
    {
        return $this->description;
    }
}